==> libreoffice-6.3.5.2.tar.xz: libreoffice-6.3.5.2/filter/source/graphicfilter/icgm/chart.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "main.hxx"
#include "chart.hxx"


CGMChart::CGMChart()
    : mnCurrentFileType(0)
{
    for ( sal_Int8 i = 0; i < 7; i++ )
    {
        mDataNode[ i ].nZoneEnum = i;
    }
}

CGMChart::~CGMChart()
{
    // delete the whole textentry structure
    for (auto & pTextEntry : maTextEntryList)
    {
        if ( pTextEntry )
            delete [] pTextEntry->pText;
    }
}

void CGMChart::InsertTextEntry( std::unique_ptr<TextEntry> pTextEntry )
{
    maTextEntryList.push_back( std::move(pTextEntry) );
}

void CGMChart::ResetAnnotation()
{
    mDataNode[ 0 ].nZoneEnum = 0;
}

bool CGMChart::IsAnnotation()
{
    return ( mDataNode[ 0 ].nZoneEnum == 0 );
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_6.4.7.orig.tar.xz: libreoffice-6.4.7/filter/source/graphicfilter/icgm/chart.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "main.hxx"
#include "chart.hxx"


CGMChart::CGMChart()
    : mnCurrentFileType(0)
{
    for ( sal_Int8 i = 0; i < 7; i++ )
    {
        mDataNode[ i ].nZoneEnum = i;
    }
}

CGMChart::~CGMChart()
{
    // delete the whole textentry structure
    for (const auto & pTextEntry : maTextEntryList)
    {
        if ( pTextEntry )
            delete [] pTextEntry->pText;
    }
}

void CGMChart::InsertTextEntry( std::unique_ptr<TextEntry> pTextEntry )
{
    maTextEntryList.push_back( std::move(pTextEntry) );
}

void CGMChart::ResetAnnotation()
{
    mDataNode[ 0 ].nZoneEnum = 0;
}

bool CGMChart::IsAnnotation() const
{
    return ( mDataNode[ 0 ].nZoneEnum == 0 );
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
